@@ -45,49 +45,51 @@
 #' circle. Parameter passed to buffer functions, default is 5 for sp and
 #' 30 for sf.
 #' @export
-#' @examples \dontrun{
+#' @examples
+#' \dontrun{
 #' data_dir <- system.file("extdata", package = "stplanr")
-#' unzip(file.path(data_dir, 'smallsa1.zip'))
-#' unzip(file.path(data_dir, 'testcycleway.zip'))
-#' sa1income <- readOGR(".","smallsa1")
-#' testcycleway <- readOGR(".","testcycleway")
+#' unzip(file.path(data_dir, "smallsa1.zip"))
+#' unzip(file.path(data_dir, "testcycleway.zip"))
+#' sa1income <- readOGR(".", "smallsa1")
+#' testcycleway <- readOGR(".", "testcycleway")
 #' calc_catchment(
-#'    polygonlayer = sa1income,
-#'    targetlayer = testcycleway,
-#'    calccols = c('Total'),
-#'    distance = 800,
-#'    projection = 'austalbers',
-#'    dissolve = TRUE
+#'   polygonlayer = sa1income,
+#'   targetlayer = testcycleway,
+#'   calccols = c("Total"),
+#'   distance = 800,
+#'   projection = "austalbers",
+#'   dissolve = TRUE
 #' )
 #' }
 calc_catchment <- function(
-  polygonlayer,
-  targetlayer,
-  calccols,
-  distance = 500,
-  projection = paste0("+proj=aea +lat_1=90 +lat_2=-18.416667 ",
-                   "+lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80",
-                   " +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"),
-  retainAreaProportion = FALSE,
-  dissolve = FALSE,
-  quadsegs = NULL
-) {
+                           polygonlayer,
+                           targetlayer,
+                           calccols,
+                           distance = 500,
+                           projection = paste0(
+                             "+proj=aea +lat_1=90 +lat_2=-18.416667 ",
+                             "+lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80",
+                             " +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
+                           ),
+                           retainAreaProportion = FALSE,
+                           dissolve = FALSE,
+                           quadsegs = NULL) {
   UseMethod(generic = "calc_catchment")
 }
 #' @export
 calc_catchment.Spatial <- function(
-  polygonlayer,
-  targetlayer,
-  calccols,
-  distance = 500,
-  projection = paste0("+proj=aea +lat_1=90 +lat_2=-18.416667 ",
-                      "+lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80",
-                      " +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"),
-  retainAreaProportion = FALSE,
-  dissolve = FALSE,
-  quadsegs = 5
-){
-
+                                   polygonlayer,
+                                   targetlayer,
+                                   calccols,
+                                   distance = 500,
+                                   projection = paste0(
+                                     "+proj=aea +lat_1=90 +lat_2=-18.416667 ",
+                                     "+lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80",
+                                     " +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
+                                   ),
+                                   retainAreaProportion = FALSE,
+                                   dissolve = FALSE,
+                                   quadsegs = 5) {
   if (projection != "skipproj") {
     confproj <- checkprojs.Spatial(polygonlayer = polygonlayer, targetlayer = targetlayer, projection = projection)
     polygonlayer <- confproj[["polygonlayer"]]
@@ -98,62 +100,75 @@ calc_catchment.Spatial <- function(
   polygonlayer@data$calc_catchment_fullArea <-
     rgeos::gArea(polygonlayer, byid = TRUE)
 
-  targetbuffer <- rgeos::gBuffer(targetlayer, width=distance, quadsegs = quadsegs, byid = TRUE)
-  polygonlayer@data$calc_catchment_charid <- paste(row.names(polygonlayer@data),targetbuffer@polygons[[1]]@ID)
+  targetbuffer <- rgeos::gBuffer(targetlayer, width = distance, quadsegs = quadsegs, byid = TRUE)
+  polygonlayer@data$calc_catchment_charid <- paste(row.names(polygonlayer@data), targetbuffer@polygons[[1]]@ID)
   polygonlayer@data$calc_catchment_charid2 <- as.character(row.names(polygonlayer@data))
   targetlayer@data$calc_catchment_charid <- as.character(row.names(targetlayer@data))
 
   targetintersect <-
     rgeos::gIntersection(polygonlayer, targetbuffer, byid = TRUE)
   targetintersect <- sp::SpatialPolygonsDataFrame(targetintersect,
-                                                  data = data.frame(
-                                                    calc_catchment_charid = sapply(targetintersect@polygons, function(x)
-                                                      x@ID),
-                                                    row.names = sapply(targetintersect@polygons, function(x)
-                                                      x@ID)
-                                                  ))
+    data = data.frame(
+      calc_catchment_charid = sapply(targetintersect@polygons, function(x)
+        x@ID),
+      row.names = sapply(targetintersect@polygons, function(x)
+        x@ID)
+    )
+  )
 
-  targetintersect@data$calc_catchment_sectArea <- rgeos::gArea(targetintersect,byid=TRUE)
+  targetintersect@data$calc_catchment_sectArea <- rgeos::gArea(targetintersect, byid = TRUE)
   targetintersect@data <- cbind(
     targetintersect@data,
     setNames(
       as.data.frame(
         t(as.data.frame(
           strsplit(
-            as.character(targetintersect@data$calc_catchment_charid), split = " "
-          )))),
-      c("calc_catchment_polygonid","calc_catchment_targetid"))
+            as.character(targetintersect@data$calc_catchment_charid),
+            split = " "
+          )
+        ))
+      ),
+      c("calc_catchment_polygonid", "calc_catchment_targetid")
     )
+  )
   targetintersect@data$calc_catchment_polygonid <- as.character(targetintersect@data$calc_catchment_polygonid)
   targetintersect@data$calc_catchment_targetid <- as.character(targetintersect@data$calc_catchment_targetid)
   targetintersect@data <- merge(targetintersect@data, polygonlayer@data,
-                                by.x = 'calc_catchment_polygonid',
-                                by.y = 'calc_catchment_charid2', all.x = TRUE)
+    by.x = "calc_catchment_polygonid",
+    by.y = "calc_catchment_charid2", all.x = TRUE
+  )
   targetintersect@data <- merge(targetintersect@data, targetlayer@data,
-                                by.x = 'calc_catchment_targetid',
-                                by.y = 'calc_catchment_charid', all.x = TRUE)
-  targetintersect@data$calc_catchment_propArea <- targetintersect@data$calc_catchment_sectArea/targetintersect@data$calc_catchment_fullArea
-  targetintersect@data[,calccols] <- targetintersect@data[,calccols]*targetintersect@data$calc_catchment_propArea
+    by.x = "calc_catchment_targetid",
+    by.y = "calc_catchment_charid", all.x = TRUE
+  )
+  targetintersect@data$calc_catchment_propArea <- targetintersect@data$calc_catchment_sectArea / targetintersect@data$calc_catchment_fullArea
+  targetintersect@data[, calccols] <- targetintersect@data[, calccols] * targetintersect@data$calc_catchment_propArea
 
 
-  if(dissolve == TRUE) {
+  if (dissolve == TRUE) {
     targetintersectd <- rgeos::gUnaryUnion(targetintersect, id = targetintersect$calc_catchment_targetid)
     targetcols <- colnames(targetlayer@data)
-    targetcols <- targetcols[which(targetcols != 'calc_catchment_charid')]
+    targetcols <- targetcols[which(targetcols != "calc_catchment_charid")]
     targetintersectd_data <- as.data.frame(
       targetintersect@data %>%
         dplyr::group_by_at(c("calc_catchment_targetid", targetcols)) %>%
         dplyr::summarise_at(
           dplyr::vars(
-            c(calccols,"calc_catchment_fullArea", "calc_catchment_sectArea")),
-          dplyr::funs("sum", .args = list("na.rm" = TRUE))))
-    rownames(targetintersectd_data) <- as.character(unlist(lapply(targetintersectd@polygons, function(x){x@ID})))
+            c(calccols, "calc_catchment_fullArea", "calc_catchment_sectArea")
+          ),
+          dplyr::funs("sum", .args = list("na.rm" = TRUE))
+        )
+    )
+    rownames(targetintersectd_data) <- as.character(unlist(lapply(targetintersectd@polygons, function(x) {
+      x@ID
+    })))
     targetintersectd <- sp::SpatialPolygonsDataFrame(targetintersectd,
-                                                     data = targetintersectd_data)
+      data = targetintersectd_data
+    )
     rm(targetintersectd_data)
-    targetintersectd@data$calc_catchment_propArea <- targetintersectd@data$calc_catchment_sectArea/targetintersectd@data$calc_catchment_fullArea
+    targetintersectd@data$calc_catchment_propArea <- targetintersectd@data$calc_catchment_sectArea / targetintersectd@data$calc_catchment_fullArea
 
-    targetintersectd@data$calc_catchment_charid <- 'charid'
+    targetintersectd@data$calc_catchment_charid <- "charid"
     targetintersect <- targetintersectd
     rm(targetintersectd)
   }
@@ -178,22 +193,21 @@ calc_catchment.Spatial <- function(
       sp::spTransform(targetintersect, sp::CRS(origprojpolygon))
   }
   return(targetintersect)
-
 }
 #' @export
 calc_catchment.sf <- function(
-  polygonlayer,
-  targetlayer,
-  calccols,
-  distance = 500,
-  projection = paste0("+proj=aea +lat_1=90 +lat_2=-18.416667 ",
-                   "+lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80",
-                   " +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"),
-  retainAreaProportion = FALSE,
-  dissolve = FALSE,
-  quadsegs = 30
-) {
-
+                              polygonlayer,
+                              targetlayer,
+                              calccols,
+                              distance = 500,
+                              projection = paste0(
+                                "+proj=aea +lat_1=90 +lat_2=-18.416667 ",
+                                "+lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80",
+                                " +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
+                              ),
+                              retainAreaProportion = FALSE,
+                              dissolve = FALSE,
+                              quadsegs = 30) {
   if (projection != "skipproj") {
     confproj <- checkprojs.sf(polygonlayer = polygonlayer, targetlayer = targetlayer, projection = projection)
     polygonlayer <- confproj[["polygonlayer"]]
@@ -210,16 +224,16 @@ calc_catchment.sf <- function(
 
 
   targetintersect$calc_catchment_sectArea <- as.numeric(sf::st_area(targetintersect))
-  targetintersect$calc_catchment_propArea <- targetintersect$calc_catchment_sectArea/targetintersect$calc_catchment_fullArea
+  targetintersect$calc_catchment_propArea <- targetintersect$calc_catchment_sectArea / targetintersect$calc_catchment_fullArea
 
-  targetintersect <- dplyr::mutate_at(targetintersect, dplyr::vars(calccols), dplyr::funs(.data$.*.data$calc_catchment_propArea))
+  targetintersect <- dplyr::mutate_at(targetintersect, dplyr::vars(calccols), dplyr::funs(.data$. * .data$calc_catchment_propArea))
 
-  if(dissolve == TRUE) {
+  if (dissolve == TRUE) {
     targetcols <- colnames(targetlayer)
-    targetcols <- targetcols[which(targetcols != 'geometry')]
+    targetcols <- targetcols[which(targetcols != "geometry")]
     targetintersect <- targetintersect %>%
       dplyr::group_by_at(targetcols) %>%
-      dplyr::summarise_at(dplyr::vars(calccols), .funs = 'sum', na.rm = TRUE)
+      dplyr::summarise_at(dplyr::vars(calccols), .funs = "sum", na.rm = TRUE)
   }
 
 
@@ -237,7 +251,6 @@ calc_catchment.sf <- function(
     targetintersect <- sf::st_transform(targetintersect, origprojpolygon)
   }
   return(targetintersect)
-
 }
 
 #' Calculate summary statistics for catchment area.
@@ -281,54 +294,57 @@ calc_catchment.sf <- function(
 #' circle. Parameter passed to buffer functions, default is 5 for sp and
 #' 30 for sf.
 #' @export
-#' @examples \dontrun{
+#' @examples
+#' \dontrun{
 #' data_dir <- system.file("extdata", package = "stplanr")
-#' unzip(file.path(data_dir, 'smallsa1.zip'))
-#' unzip(file.path(data_dir, 'testcycleway.zip'))
-#' sa1income <- readOGR(".","smallsa1")
-#' testcycleway <- readOGR(".","testcycleway")
+#' unzip(file.path(data_dir, "smallsa1.zip"))
+#' unzip(file.path(data_dir, "testcycleway.zip"))
+#' sa1income <- readOGR(".", "smallsa1")
+#' testcycleway <- readOGR(".", "testcycleway")
 #' calc_catchment_sum(
-#'    polygonlayer = sa1income,
-#'    targetlayer = testcycleway,
-#'    calccols = c('Total'),
-#'    distance = 800,
-#'    projection = 'austalbers'
+#'   polygonlayer = sa1income,
+#'   targetlayer = testcycleway,
+#'   calccols = c("Total"),
+#'   distance = 800,
+#'   projection = "austalbers"
 #' )
-#'
+#' 
 #' calc_catchment_sum(
-#' polygonlayer = sa1income,
-#' targetlayer = testcycleway,
-#' calccols = c('Total'),
-#' distance = 800,
-#' projection = 'austalbers'
+#'   polygonlayer = sa1income,
+#'   targetlayer = testcycleway,
+#'   calccols = c("Total"),
+#'   distance = 800,
+#'   projection = "austalbers"
 #' )
 #' }
 calc_catchment_sum <- function(
-  polygonlayer,
-  targetlayer,
-  calccols,
-  distance = 500,
-  projection = paste0("+proj=aea +lat_1=90 +lat_2=-18.416667",
-                      " +lat_0=0 +lon_0=10 +x_0=0 +y_0=0",
-                      " +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"),
-  retainAreaProportion = FALSE,
-  quadsegs = NA
-){
+                               polygonlayer,
+                               targetlayer,
+                               calccols,
+                               distance = 500,
+                               projection = paste0(
+                                 "+proj=aea +lat_1=90 +lat_2=-18.416667",
+                                 " +lat_0=0 +lon_0=10 +x_0=0 +y_0=0",
+                                 " +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
+                               ),
+                               retainAreaProportion = FALSE,
+                               quadsegs = NA) {
   UseMethod(generic = "calc_catchment_sum")
 }
 #' @export
 calc_catchment_sum.Spatial <- function(
-  polygonlayer,
-  targetlayer,
-  calccols,
-  distance = 500,
-  projection = paste0("+proj=aea +lat_1=90 +lat_2=-18.416667",
-                      " +lat_0=0 +lon_0=10 +x_0=0 +y_0=0",
-                      " +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"),
-  retainAreaProportion = FALSE,
-  quadsegs = 5
-){
-  if(length(calccols) == 1) {
+                                       polygonlayer,
+                                       targetlayer,
+                                       calccols,
+                                       distance = 500,
+                                       projection = paste0(
+                                         "+proj=aea +lat_1=90 +lat_2=-18.416667",
+                                         " +lat_0=0 +lon_0=10 +x_0=0 +y_0=0",
+                                         " +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
+                                       ),
+                                       retainAreaProportion = FALSE,
+                                       quadsegs = 5) {
+  if (length(calccols) == 1) {
     return(sum(calc_catchment(
       polygonlayer = polygonlayer,
       targetlayer = targetlayer,
@@ -338,7 +354,7 @@ calc_catchment_sum.Spatial <- function(
       retainAreaProportion = retainAreaProportion,
       dissolve = FALSE,
       quadsegs = quadsegs
-    )@data[,calccols],na.rm = TRUE))
+    )@data[, calccols], na.rm = TRUE))
   } else {
     return(colSums(calc_catchment(
       polygonlayer = polygonlayer,
@@ -349,23 +365,24 @@ calc_catchment_sum.Spatial <- function(
       retainAreaProportion = retainAreaProportion,
       dissolve = FALSE,
       quadsegs = quadsegs
-    )@data[,calccols],na.rm = TRUE))
+    )@data[, calccols], na.rm = TRUE))
   }
 }
 
 #' @export
 calc_catchment_sum.sf <- function(
-  polygonlayer,
-  targetlayer,
-  calccols,
-  distance = 500,
-  projection = paste0("+proj=aea +lat_1=90 +lat_2=-18.416667",
-                      " +lat_0=0 +lon_0=10 +x_0=0 +y_0=0",
-                      " +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"),
-  retainAreaProportion = FALSE,
-  quadsegs = 30
-){
-  if(length(calccols) == 1) {
+                                  polygonlayer,
+                                  targetlayer,
+                                  calccols,
+                                  distance = 500,
+                                  projection = paste0(
+                                    "+proj=aea +lat_1=90 +lat_2=-18.416667",
+                                    " +lat_0=0 +lon_0=10 +x_0=0 +y_0=0",
+                                    " +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
+                                  ),
+                                  retainAreaProportion = FALSE,
+                                  quadsegs = 30) {
+  if (length(calccols) == 1) {
     return(sum(as.data.frame(calc_catchment(
       polygonlayer = polygonlayer,
       targetlayer = targetlayer,
@@ -375,7 +392,7 @@ calc_catchment_sum.sf <- function(
       retainAreaProportion = retainAreaProportion,
       dissolve = FALSE,
       quadsegs = quadsegs
-    ))[,calccols],na.rm = TRUE))
+    ))[, calccols], na.rm = TRUE))
   } else {
     return(colSums(as.data.frame(calc_catchment(
       polygonlayer = polygonlayer,
@@ -386,7 +403,7 @@ calc_catchment_sum.sf <- function(
       retainAreaProportion = retainAreaProportion,
       dissolve = FALSE,
       quadsegs = quadsegs
-    ))[,calccols],na.rm = TRUE))
+    ))[, calccols], na.rm = TRUE))
   }
 }
 
@@ -425,29 +442,29 @@ calc_catchment_sum.sf <- function(
 #' the resulting SpatialPolygonsDataFrame containing the proportion of the
 #' original area within the catchment area (Default = FALSE).
 #' @export
-#' @examples \dontrun{
+#' @examples
+#' \dontrun{
 #' data_dir <- system.file("extdata", package = "stplanr")
-#' unzip(file.path(data_dir, 'smallsa1.zip'))
-#' unzip(file.path(data_dir, 'testcycleway.zip'))
-#' sa1income <- readOGR(".","smallsa1")
-#' testcycleway <- readOGR(".","testcycleway")
+#' unzip(file.path(data_dir, "smallsa1.zip"))
+#' unzip(file.path(data_dir, "testcycleway.zip"))
+#' sa1income <- readOGR(".", "smallsa1")
+#' testcycleway <- readOGR(".", "testcycleway")
 #' calc_moving_catchment(
-#'    polygonlayer = sa1income,
-#'    targetlayer = testcycleway,
-#'    calccols = c('Total'),
-#'    distance = 800,
-#'    projection = 'austalbers'
+#'   polygonlayer = sa1income,
+#'   targetlayer = testcycleway,
+#'   calccols = c("Total"),
+#'   distance = 800,
+#'   projection = "austalbers"
 #' )
 #' }
 calc_moving_catchment <- function(
-  polygonlayer,
-  targetlayer,
-  calccols,
-  distance = 500,
-  projection = 'worldalbers',
-  retainAreaProportion = FALSE
-){
-  newcalccols <- paste0('sum_',calccols)
+                                  polygonlayer,
+                                  targetlayer,
+                                  calccols,
+                                  distance = 500,
+                                  projection = "worldalbers",
+                                  retainAreaProportion = FALSE) {
+  newcalccols <- paste0("sum_", calccols)
 
   confproj <- checkprojs.Spatial(polygonlayer = polygonlayer, targetlayer = targetlayer, projection = projection)
 
@@ -525,24 +542,25 @@ calc_moving_catchment <- function(
 #' within the catchment area into a single region with statistics for the
 #' whole catchment area.
 #' @export
-#' @examples \dontrun{
+#' @examples
+#' \dontrun{
 #' data_dir <- system.file("extdata", package = "stplanr")
-#' unzip(file.path(data_dir, 'smallsa1.zip'), exdir=tempdir())
-#' unzip(file.path(data_dir, 'testcycleway.zip'), exdir=tempdir())
-#' unzip(file.path(data_dir, 'sydroads.zip'), exdir=tempdir())
-#' sa1income <- readOGR(tempdir(),"smallsa1")
-#' testcycleway <- readOGR(tempdir(),"testcycleway")
-#' sydroads <- readOGR(tempdir(),"roads")
+#' unzip(file.path(data_dir, "smallsa1.zip"), exdir = tempdir())
+#' unzip(file.path(data_dir, "testcycleway.zip"), exdir = tempdir())
+#' unzip(file.path(data_dir, "sydroads.zip"), exdir = tempdir())
+#' sa1income <- readOGR(tempdir(), "smallsa1")
+#' testcycleway <- readOGR(tempdir(), "testcycleway")
+#' sydroads <- readOGR(tempdir(), "roads")
 #' sydnetwork <- SpatialLinesNetwork(sydroads)
 #' calc_network_catchment(
-#'    sln = sydnetwork,
-#'    polygonlayer = sa1income,
-#'    targetlayer = testcycleway,
-#'    calccols = c('Total'),
-#'    maximpedance = 800,
-#'    distance = 200,
-#'    projection = 'austalbers',
-#'    dissolve = TRUE
+#'   sln = sydnetwork,
+#'   polygonlayer = sa1income,
+#'   targetlayer = testcycleway,
+#'   calccols = c("Total"),
+#'   maximpedance = 800,
+#'   distance = 200,
+#'   projection = "austalbers",
+#'   dissolve = TRUE
 #' )
 #' }
 calc_network_catchment <- function(sln,
@@ -563,73 +581,76 @@ calc_network_catchment <- function(sln,
     ifelse(longlat == TRUE, maximpedance / 1000, maximpedance)
 
   if (is(targetlayer, "SpatialLines") |
-      is(targetlayer, "SpatialLinesDataFrame") |
-      is(targetlayer, "SpatialPolygons") |
-      is(targetlayer, "SpatialPolygonsDataFrame") |
-      is(targetlayer, "SpatialPoints") |
-      is(targetlayer, "SpatialPointsDataFrame")) {
+    is(targetlayer, "SpatialLinesDataFrame") |
+    is(targetlayer, "SpatialPolygons") |
+    is(targetlayer, "SpatialPolygonsDataFrame") |
+    is(targetlayer, "SpatialPoints") |
+    is(targetlayer, "SpatialPointsDataFrame")) {
     if (sln@sl@proj4string@projargs != targetlayer@proj4string@projargs) {
       newtargetlayer <- sp::spTransform(targetlayer, sln@sl@proj4string)
     }
     else {
       newtargetlayer <- targetlayer
     }
-    #targetnodes <- unique(find_network_nodes(sln, as.data.frame(coordinates(newtargetlayer))))
+    # targetnodes <- unique(find_network_nodes(sln, as.data.frame(coordinates(newtargetlayer))))
     if (is(targetlayer, "SpatialPoints") |
-        is(targetlayer, "SpatialPointsDataFrame")) {
-
+      is(targetlayer, "SpatialPointsDataFrame")) {
       targetnodes <- unique(find_network_nodes(sln, as.data.frame(unique(
         coordinates(newtargetlayer)
       ))))
     } else {
       targetnodes <- unique(find_network_nodes(sln, as.data.frame(unique(
         do.call(rbind, unlist(
-          coordinates(newtargetlayer), recursive = FALSE
+          coordinates(newtargetlayer),
+          recursive = FALSE
         ))
       ))))
     }
     spaths <- lapply(targetnodes, function(x) {
-
       igraph::get.shortest.paths(sln@g, x,
-                                 # which(sp::spDists(
-                                 #   x = as.matrix(data.frame(x=sln@g$x, y=sln@g$y)),
-                                 #   y = matrix(cbind(sln@g$x,sln@g$y)[x,],ncol=2),
-                                 #   longlat = longlat
-                                 # ) <= maximpedance),
-                                 output = "epath")
+        # which(sp::spDists(
+        #   x = as.matrix(data.frame(x=sln@g$x, y=sln@g$y)),
+        #   y = matrix(cbind(sln@g$x,sln@g$y)[x,],ncol=2),
+        #   longlat = longlat
+        # ) <= maximpedance),
+        output = "epath"
+      )
     })
 
     spaths <-
       unlist(lapply(spaths, function(x) {
         x$epath
       }), recursive = FALSE)
-
   }
 
   else {
     spaths <- igraph::get.shortest.paths(sln@g,
-                                         targetlayer,
-                                         which(
-                                           sp::spDists(
-                                             x = as.matrix(data.frame(x = sln@g$x, y = sln@g$y)),
-                                             y = matrix(cbind(sln@g$x, sln@g$y)[targetlayer, ], ncol =
-                                                          2),
-                                             longlat = longlat
-                                           ) <= maximpedance
-                                         ),
-                                         output = "epath")
+      targetlayer,
+      which(
+        sp::spDists(
+          x = as.matrix(data.frame(x = sln@g$x, y = sln@g$y)),
+          y = matrix(cbind(sln@g$x, sln@g$y)[targetlayer, ],
+            ncol =
+              2
+          ),
+          longlat = longlat
+        ) <= maximpedance
+      ),
+      output = "epath"
+    )
     spaths <- spaths$epath
-
   }
 
-  uniquesects <- unique(unlist(lapply(spaths,
-                                      function(x) {
-                                        if (length(x) > 0) {
-                                          if (sum(sln@sl@data[x, sln@weightfield], na.rm = TRUE) <= maximpedance) {
-                                            x
-                                          }
-                                        }
-                                      })))
+  uniquesects <- unique(unlist(lapply(
+    spaths,
+    function(x) {
+      if (length(x) > 0) {
+        if (sum(sln@sl@data[x, sln@weightfield], na.rm = TRUE) <= maximpedance) {
+          x
+        }
+      }
+    }
+  )))
 
   calc_catchment(
     polygonlayer = polygonlayer,
@@ -640,13 +661,14 @@ calc_network_catchment <- function(sln,
     retainAreaProportion = retainAreaProportion,
     dissolve = dissolve
   )
-
 }
 
 checkprojs.Spatial <- function(polygonlayer, targetlayer, projection) {
   # Define Named vector of known projection strings
-  knownprojs <- c('austalbers' = '+proj=aea +lat_1=-18 +lat_2=-36 +lat_0=0 +lon_0=132 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs',
-                  'worldalbers' = '+proj=aea +lat_1=90 +lat_2=-18.416667 +lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs')
+  knownprojs <- c(
+    "austalbers" = "+proj=aea +lat_1=-18 +lat_2=-36 +lat_0=0 +lon_0=132 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs",
+    "worldalbers" = "+proj=aea +lat_1=90 +lat_2=-18.416667 +lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
+  )
 
   if (sum(is.na(knownprojs[projection])) == 0) {
     projection <- knownprojs[projection]
@@ -661,23 +683,23 @@ checkprojs.Spatial <- function(polygonlayer, targetlayer, projection) {
     polygonlayer <- sp::spTransform(polygonlayer, sp::CRS(projection))
     targetlayer <- sp::spTransform(targetlayer, sp::CRS(projection))
   } else if (polyproj == TRUE & lineproj == FALSE) {
-    projection = sp::proj4string(polygonlayer)
+    projection <- sp::proj4string(polygonlayer)
     targetlayer <- sp::spTransform(targetlayer, sp::CRS(projection))
   } else if (polyproj == TRUE & lineproj == TRUE) {
     if (sp::proj4string(polygonlayer) != sp::proj4string(targetlayer)) {
-      projection = sp::proj4string(polygonlayer)
+      projection <- sp::proj4string(polygonlayer)
       targetlayer <-
         sp::spTransform(targetlayer, sp::CRS(projection))
     }
   }
-  return(list("polygonlayer"=polygonlayer,"targetlayer"=targetlayer,"origprojpolygon"=origprojpolygon))
+  return(list("polygonlayer" = polygonlayer, "targetlayer" = targetlayer, "origprojpolygon" = origprojpolygon))
 }
 
 checkprojs.sf <- function(polygonlayer, targetlayer, projection) {
   # Define Named vector of known projection strings
   knownprojs <- c(
-    'austalbers'='+proj=aea +lat_1=-18 +lat_2=-36 +lat_0=0 +lon_0=132 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs',
-    'worldalbers'='+proj=aea +lat_1=90 +lat_2=-18.416667 +lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs'
+    "austalbers" = "+proj=aea +lat_1=-18 +lat_2=-36 +lat_0=0 +lon_0=132 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs",
+    "worldalbers" = "+proj=aea +lat_1=90 +lat_2=-18.416667 +lat_0=0 +lon_0=10 +x_0=0 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
   )
 
   if (sum(is.na(knownprojs[projection])) == 0) {
@@ -690,7 +712,6 @@ checkprojs.sf <- function(polygonlayer, targetlayer, projection) {
   origprojpolygon <- sf::st_crs(polygonlayer)
 
   if (polyproj == FALSE & lineproj == FALSE) {
-
     polygonlayer <- sf::st_transform(polygonlayer, projection)
     targetlayer <- sf::st_transform(targetlayer, projection)
   } else if (polyproj == TRUE & lineproj == FALSE) {
@@ -702,5 +723,5 @@ checkprojs.sf <- function(polygonlayer, targetlayer, projection) {
       targetlayer <- sf::st_transform(targetlayer, projection)
     }
   }
-  return(list("polygonlayer"=polygonlayer,"targetlayer"=targetlayer,"origprojpolygon"=origprojpolygon))
-}
\ No newline at end of file
+  return(list("polygonlayer" = polygonlayer, "targetlayer" = targetlayer, "origprojpolygon" = origprojpolygon))
+}
