@@ -6,7 +6,7 @@
 #' for data collected anywhere in the world.
 #'
 #' The function is based on this stackexchange answer:
-#' \url{http://gis.stackexchange.com/questions/121489}
+#' <http://gis.stackexchange.com/questions/121489>
 #'
 #' @param shp A spatial object with a geographic (WGS84) coordinate system
 #' @export
@@ -20,10 +20,12 @@
 #' line_length <- rgeos::gLength(rf_projected, byid = TRUE)
 #' plot(line_length, rf_projected$length)
 #' cor(line_length, rf_projected$length)
-crs_select_aeq <- function(shp){
+crs_select_aeq <- function(shp) {
   cent <- rgeos::gCentroid(shp)
-  aeqd <- sprintf("+proj=aeqd +lat_0=%s +lon_0=%s +x_0=0 +y_0=0",
-          cent@coords[[2]], cent@coords[[1]])
+  aeqd <- sprintf(
+    "+proj=aeqd +lat_0=%s +lon_0=%s +x_0=0 +y_0=0",
+    cent@coords[[2]], cent@coords[[1]]
+  )
   sp::CRS(aeqd)
 }
 #' Reproject lat/long spatial object so that they are in units of 1m
@@ -32,21 +34,21 @@ crs_select_aeq <- function(shp){
 #'
 #' @param shp A spatial object with a geographic (WGS84) coordinate system
 #' @param crs An optional coordinate reference system (if not provided it is set
-#' automatically by \code{\link{crs_select_aeq}}).
+#' automatically by [crs_select_aeq()]).
 #' @export
 #' @examples
 #' data(routes_fast)
-#' rf_aeq = reproject(routes_fast[1:3, ])
-#' rf_osgb = reproject(routes_fast[1:3, ], 27700)
-reproject <- function(shp, crs = crs_select_aeq(shp)){
-  if(is.na(raster::crs(shp))){
+#' rf_aeq <- reproject(routes_fast[1:3, ])
+#' rf_osgb <- reproject(routes_fast[1:3, ], 27700)
+reproject <- function(shp, crs = crs_select_aeq(shp)) {
+  if (is.na(raster::crs(shp))) {
     message("Assuming a geographical (lat/lon) CRS (EPSG:4326)")
-    raster::crs(shp) = sp::CRS("+init=epsg:4326")
+    raster::crs(shp) <- sp::CRS("+init=epsg:4326")
+  }
+  if (is.numeric(crs)) { # test if it's an epsg code
+    crs <- sp::CRS(paste0("+init=epsg:", crs))
   }
-  if(is.numeric(crs)) # test if it's an epsg code
-    crs = sp::CRS(paste0("+init=epsg:", crs))
   message(paste0("Transforming to CRS ", crs))
-  res = sp::spTransform(shp, crs)
+  res <- sp::spTransform(shp, crs)
   res
 }
-
