@@ -4,7 +4,7 @@
 #' and returns a matrix of coordinates representing origin (fx, fy) and destination (tx, ty) points.
 #'
 #' @param from An object representing origins
-#' (if lines are provided as the first argument, from is assigned to \code{l})
+#' (if lines are provided as the first argument, from is assigned to `l`)
 #' @param to An object representing destinations
 #' @param l Only needed if from and to are empty, in which case this
 #' should be a spatial object representing desire lines
@@ -17,36 +17,35 @@
 #' od_coords(flowlines[1:3, ])
 #' od_coords(flowlines_sf[1:3, ])
 od_coords <- function(from = NULL, to = NULL, l = NULL) {
-
-  if(is(object = from, class2 = "sf")) {
+  if (is(object = from, class2 = "sf")) {
     is_sf_line <- all(sf::st_geometry_type(from) == "LINESTRING")
   } else {
     is_sf_line <- FALSE
   }
 
-  if(is_sf_line | any(grepl(pattern = "Line", x = class(from)))) {
+  if (is_sf_line | any(grepl(pattern = "Line", x = class(from)))) {
     l <- from
   }
 
-  if(!is.null(l)) {
+  if (!is.null(l)) {
     coord_matrix <- line2df(l) %>%
       dplyr::select("fx", "fy", "tx", "ty")
   }
 
   else {
     # Convert sp object to lat/lon vector
-    if(is(object = from, "Spatial")) from <- sp::coordinates(from)
-    if(is(object = to, "Spatial")) to <- sp::coordinates(to)
+    if (is(object = from, "Spatial")) from <- sp::coordinates(from)
+    if (is(object = to, "Spatial")) to <- sp::coordinates(to)
 
     # sf objects
-    if(is(object = from, "sf")) from <- sf::st_coordinates(from)
-    if(is(object = to, "sf")) to <- sf::st_coordinates(to)
+    if (is(object = from, "sf")) from <- sf::st_coordinates(from)
+    if (is(object = to, "sf")) to <- sf::st_coordinates(to)
 
     # Convert character strings to lon/lat if needs be
-    if(is.character(from)) from <- matrix(geo_code(from), ncol = 2)
-    if(is.character(to)) to <- matrix(geo_code(to), ncol = 2)
-    if(is.vector(from) & is.vector(to)) {
-      coord_matrix = matrix(c(from, to), ncol = 4)
+    if (is.character(from)) from <- matrix(geo_code(from), ncol = 2)
+    if (is.character(to)) to <- matrix(geo_code(to), ncol = 2)
+    if (is.vector(from) & is.vector(to)) {
+      coord_matrix <- matrix(c(from, to), ncol = 4)
     } else {
       coord_matrix <- cbind(from, to)
     }
@@ -54,5 +53,4 @@ od_coords <- function(from = NULL, to = NULL, l = NULL) {
   }
 
   coord_matrix
-
 }
