@@ -3,7 +3,7 @@
 #' Takes lines and removes the start and end point, to a distance determined
 #' by the user.
 #'
-#' Note: \code{\link{toptailgs}} is around 10 times faster, but only works
+#' Note: [toptailgs()] is around 10 times faster, but only works
 #' on data with geographic CRS's due to its reliance on the geosphere
 #' package.
 #'
@@ -15,7 +15,7 @@
 #' @aliases toptail
 #' @export
 #' @examples
-#' l = routes_fast[2:4,]
+#' l <- routes_fast[2:4, ]
 #' l_toptail <- geo_toptail(l, toptail_dist = 300)
 #' plot(l)
 #' plot(l_toptail, col = "red", add = TRUE, lwd = 3)
@@ -28,36 +28,36 @@ geo_toptail <- function(l, toptail_dist, ...) {
   UseMethod("geo_toptail")
 }
 #' @export
-geo_toptail.Spatial <- toptail <- function(l, toptail_dist, ...){
-
-  if(length(toptail_dist) > 1 & length(toptail_dist) != length(l)) {
+geo_toptail.Spatial <- toptail <- function(l, toptail_dist, ...) {
+  if (length(toptail_dist) > 1 & length(toptail_dist) != length(l)) {
     stop("toptail_dist is vector but not of equal length to spatial object")
   }
 
   lpoints <- line_to_points(l)
 
-  if(length(toptail_dist) == 1) {
-    toptail_dist = rep(toptail_dist, length(l))
+  if (length(toptail_dist) == 1) {
+    toptail_dist <- rep(toptail_dist, length(l))
   }
 
-  for(i in 1:length(l)){
-
-    sel_points <- lpoints[lpoints$id == i,]
+  for (i in 1:length(l)) {
+    sel_points <- lpoints[lpoints$id == i, ]
 
     # Create buffer for geographic or projected crs
-    if(!sp::is.projected(l)){
+    if (!sp::is.projected(l)) {
       sel <- geo_buffer(lpoints, width = toptail_dist[i], ..., silent = TRUE)
     } else {
       sel <- rgeos::gBuffer(lpoints, dist = toptail_dist[i], ...)
     }
 
-    if(rgeos::gContainsProperly(sel, l[i,])){
-      message(paste0("Line ", i, " is completely removed by the clip and",
-                   " is omitted from the results"))
+    if (rgeos::gContainsProperly(sel, l[i, ])) {
+      message(paste0(
+        "Line ", i, " is completely removed by the clip and",
+        " is omitted from the results"
+      ))
       next
     }
-    l2 <- rgeos::gDifference(l[i,], sel)
-    if(!exists("out")){
+    l2 <- rgeos::gDifference(l[i, ], sel)
+    if (!exists("out")) {
       out <- l2
     } else {
       out <- raster::bind(out, l2)
@@ -66,7 +66,7 @@ geo_toptail.Spatial <- toptail <- function(l, toptail_dist, ...){
   out
 }
 #' @export
-geo_toptail.sf <- function(l, toptail_dist, ...){
+geo_toptail.sf <- function(l, toptail_dist, ...) {
   l_sp <- as(l, "Spatial")
   res_sp <- geo_toptail(l = l_sp, toptail_dist = toptail_dist, ...)
   sf::st_as_sf(res_sp)
@@ -81,19 +81,19 @@ geo_toptail.sf <- function(l, toptail_dist, ...){
 #' @inheritParams geo_buffer
 #' @export
 #' @examples
-#' r = routes_fast[1:3, ]
+#' r <- routes_fast[1:3, ]
 #' buff <- buff_geo(r, width = 100)
 #' plot(buff)
 #' plot(r, add = TRUE)
 #' # Test it works the same on projected data
 #' shp <- sp::spTransform(r, sp::CRS("+init=epsg:27700"))
-#' buff2 = buff_geo(shp, 50) # test if it works the same on projected data
+#' buff2 <- buff_geo(shp, 50) # test if it works the same on projected data
 #' plot(buff2)
 #' plot(r, add = TRUE) # note they do not show
-#' buff3 = sp::spTransform(buff2, sp::CRS("+init=epsg:4326"))
+#' buff3 <- sp::spTransform(buff2, sp::CRS("+init=epsg:4326"))
 #' plot(buff)
 #' plot(buff3, add = TRUE, col = "black")
-buff_geo <- function(shp, width, ...){
+buff_geo <- function(shp, width, ...) {
   gprojected(shp = shp, fun = rgeos::gBuffer, width = width, ...)
 }
 #' Clip the first and last n metres of SpatialLines
@@ -112,13 +112,12 @@ buff_geo <- function(shp, width, ...){
 #' @export
 #' @examples
 #' data("routes_fast")
-#' rf = routes_fast[2:3, ]
+#' rf <- routes_fast[2:3, ]
 #' r_toptail <- toptailgs(rf, toptail_dist = 300)
 #' plot(rf, lwd = 3)
 #' plot(r_toptail, col = "red", add = TRUE)
 #' plot(cents, add = TRUE)
 toptailgs <- function(l, toptail_dist, tail_dist = NULL) {
-
   if (length(toptail_dist) > 1) {
     if (length(toptail_dist) != length(l)) {
       stop("toptail_dist is vector but not of equal length to SpatialLines object")
@@ -139,29 +138,29 @@ toptailgs <- function(l, toptail_dist, tail_dist = NULL) {
   tail_disto <- tail_dist
 
   i <- 1
-  while(i <= length(l)) {
+  while (i <= length(l)) {
     toptail_dist <- ifelse(length(toptail_disto) == 1, toptail_disto, toptail_disto[i])
     linecoords <- coordinates(l@lines[[i]])[[1]]
-    topdists <- geosphere::distHaversine(linecoords[1,],linecoords)
+    topdists <- geosphere::distHaversine(linecoords[1, ], linecoords)
     linecoords <- rbind(
-      tail(linecoords[which(topdists < toptail_dist),,drop=FALSE],n=1)+(
-        linecoords[which(topdists >= toptail_dist),,drop=FALSE][1,]-
-          tail(linecoords[which(topdists < toptail_dist),,drop=FALSE],n=1)
-      )*(
-        (toptail_dist-tail(topdists[which(topdists < toptail_dist)],n=1))/(topdists[which(topdists >= toptail_dist)][1]-tail(topdists[which(topdists < toptail_dist)],n=1))
+      tail(linecoords[which(topdists < toptail_dist), , drop = FALSE], n = 1) + (
+        linecoords[which(topdists >= toptail_dist), , drop = FALSE][1, ] -
+          tail(linecoords[which(topdists < toptail_dist), , drop = FALSE], n = 1)
+      ) * (
+        (toptail_dist - tail(topdists[which(topdists < toptail_dist)], n = 1)) / (topdists[which(topdists >= toptail_dist)][1] - tail(topdists[which(topdists < toptail_dist)], n = 1))
       ),
-      linecoords[which(topdists >= toptail_dist),,drop=FALSE]
+      linecoords[which(topdists >= toptail_dist), , drop = FALSE]
     )
-    bottomdists <- geosphere::distHaversine(linecoords[nrow(linecoords),],linecoords)
+    bottomdists <- geosphere::distHaversine(linecoords[nrow(linecoords), ], linecoords)
     tail_dist <- ifelse(length(tail_disto) == 1, tail_disto, tail_disto[i])
 
     linecoords <- rbind(
-      linecoords[which(bottomdists >= tail_dist),,drop=FALSE],
-      tail(linecoords[which(bottomdists >= tail_dist),,drop=FALSE],n=1)+(
-        linecoords[which(bottomdists < tail_dist),,drop=FALSE][1,]-
-          tail(linecoords[which(bottomdists >= tail_dist),,drop=FALSE],n=1)
-      )*
-        ((tail(bottomdists[which(bottomdists >= tail_dist)],n=1)-tail_dist)/(tail(bottomdists[which(bottomdists >= tail_dist)],n=1)-bottomdists[which(bottomdists < tail_dist)][1]))
+      linecoords[which(bottomdists >= tail_dist), , drop = FALSE],
+      tail(linecoords[which(bottomdists >= tail_dist), , drop = FALSE], n = 1) + (
+        linecoords[which(bottomdists < tail_dist), , drop = FALSE][1, ] -
+          tail(linecoords[which(bottomdists >= tail_dist), , drop = FALSE], n = 1)
+      ) *
+        ((tail(bottomdists[which(bottomdists >= tail_dist)], n = 1) - tail_dist) / (tail(bottomdists[which(bottomdists >= tail_dist)], n = 1) - bottomdists[which(bottomdists < tail_dist)][1]))
     )
     l@lines[[i]]@Lines[[1]]@coords <- unname(linecoords)
     i <- i + 1
@@ -182,28 +181,28 @@ toptailgs <- function(l, toptail_dist, tail_dist = NULL) {
 #' @examples
 #' r_toptail <- toptail_buff(routes_fast, zones)
 #' sel <- row.names(routes_fast) %in% row.names(r_toptail)
-#' rf_cross_poly <- routes_fast[sel,]
+#' rf_cross_poly <- routes_fast[sel, ]
 #' plot(zones)
 #' plot(routes_fast, col = "blue", lwd = 4, add = TRUE)
 #' # note adjacent lines removed
 #' plot(rf_cross_poly, add = TRUE, lwd = 2)
 #' plot(r_toptail, col = "red", add = TRUE)
-toptail_buff <- function(l, buff, ...){
+toptail_buff <- function(l, buff, ...) {
   # force same crs
-  if(!sp::identicalCRS(l, buff)){
+  if (!sp::identicalCRS(l, buff)) {
     sp::proj4string(buff) <- sp::proj4string(l)
   }
-  for(i in 1:length(l)){
-    lpoints <- line2points(l[i,])
+  for (i in 1:length(l)) {
+    lpoints <- line2points(l[i, ])
     # Select zones per line
-    sel <- buff[lpoints,]
-    l2 <- rgeos::gDifference(l[i,], sel)
-    if(is.null(l2)){
+    sel <- buff[lpoints, ]
+    l2 <- rgeos::gDifference(l[i, ], sel)
+    if (is.null(l2)) {
       next
-    }else{
-      row.names(l2) <- row.names(l[i,])
+    } else {
+      row.names(l2) <- row.names(l[i, ])
     }
-    if(!exists("out")){
+    if (!exists("out")) {
       out <- l2
     } else {
       out <- raster::bind(out, l2)
